@@ -13,7 +13,7 @@ setup
 
 
 if [ "${OFFLINE}" != "yes" ]; then
-  pip install -U -r requirements_dev.txt
+  pip install -U --upgrade-strategy eager -e ".[dev]"
 fi
 
 
